#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmorph
version:              1.2.0
visibility:           public
id:                   mmorph-1.2.0-CEfy45MbYHHKyxdKlNJq5E
key:                  mmorph-1.2.0-CEfy45MbYHHKyxdKlNJq5E
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.

category:             Control
abi:                  790a6e66891a55da08d5c5b96915ec6c
exposed:              True
exposed-modules:      Control.Monad.Morph Control.Monad.Trans.Compose
import-dirs:          /usr/lib/ghc-8.10.5/site-local/mmorph-1.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mmorph-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mmorph-1.2.0
hs-libraries:         HSmmorph-1.2.0-CEfy45MbYHHKyxdKlNJq5E
depends:
    base-4.14.2.0 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.7-DEkprM8uNQhJDKKPf6L2ns

haddock-interfaces:   /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html:         /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

